summaryrefslogtreecommitdiffstats
path: root/kio/bookmarks/kbookmarkdrag.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kio/bookmarks/kbookmarkdrag.cc')
-rw-r--r--kio/bookmarks/kbookmarkdrag.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/kio/bookmarks/kbookmarkdrag.cc b/kio/bookmarks/kbookmarkdrag.cc
index d13893eed..358e329a9 100644
--- a/kio/bookmarks/kbookmarkdrag.cc
+++ b/kio/bookmarks/kbookmarkdrag.cc
@@ -54,8 +54,8 @@ KBookmarkDrag::KBookmarkDrag( const TQValueList<KBookmark> & bookmarks, const TQ
: TQUriDrag( urls, dragSource, name ), m_bookmarks( bookmarks ), m_doc("xbel")
{
// We need to create the XML for this drag right now and not
// in encodedData because when cutting a folder, the children
// wouldn't be part of the bookmarks anymore, when encodedData
// is requested.
TQDomElement elem = m_doc.createElement("xbel");
m_doc.appendChild( elem );
@@ -76,16 +76,16 @@ const char* KBookmarkDrag::format( int i ) const
else return 0;
}
-TQByteArray KBookmarkDrag::encodedData( const char* mime ) const
+TQByteArray KBookmarkDrag::tqencodedData( const char* mime ) const
{
TQByteArray a;
TQCString mimetype( mime );
if ( mimetype == "text/uri-list" )
- return TQUriDrag::encodedData( mime );
+ return TQUriDrag::tqencodedData( mime );
else if ( mimetype == "application/x-xbel" )
{
a = m_doc.toCString();
- //kdDebug(7043) << "KBookmarkDrag::encodedData " << m_doc.toCString() << endl;
+ //kdDebug(7043) << "KBookmarkDrag::tqencodedData " << m_doc.toCString() << endl;
}
else if ( mimetype == "text/plain" )
{
@@ -117,7 +117,7 @@ TQValueList<KBookmark> KBookmarkDrag::decode( const TQMimeSource * e )
TQValueList<KBookmark> bookmarks;
if ( e->provides("application/x-xbel") )
{
- TQByteArray s( e->encodedData("application/x-xbel") );
+ TQByteArray s( e->tqencodedData("application/x-xbel") );
//kdDebug(7043) << "KBookmarkDrag::decode s=" << TQCString(s) << endl;
TQDomDocument doc;
doc.setContent( s );
@@ -54,8 +54,8 @@ KBookmarkDrag::KBookmarkDrag( const TQValueList<KBookmark> & bookmarks, const TQ
{
// We need to create the XML for this drag right now and not
- // in encodedData because when cutting a folder, the children
- // wouldn't be part of the bookmarks anymore, when encodedData
+ // in tqencodedData because when cutting a folder, the children
+ // wouldn't be part of the bookmarks anymore, when tqencodedData
// is requested.
TQDomElement elem = m_doc.createElement("xbel");